==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/ec2/kotlin/inputs/InstanceNetworkInterfaceArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.ec2.kotlin.inputs

import com.pulumi.aws.ec2.inputs.InstanceNetworkInterfaceArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property deleteOnTermination Whether or not to delete the network interface on instance termination. Defaults to `false`. Currently, the only valid value is `false`, as this is only supported when creating new network interfaces when launching an instance.
 * @property deviceIndex Integer index of the network interface attachment. Limited by instance type.
 * @property networkCardIndex Integer index of the network card. Limited by instance type. The default index is `0`.
 * @property networkInterfaceId ID of the network interface to attach.
 */
public data class InstanceNetworkInterfaceArgs(
    public val deleteOnTermination: Output<Boolean>? = null,
    public val deviceIndex: Output<Int>,
    public val networkCardIndex: Output<Int>? = null,
    public val networkInterfaceId: Output<String>,
) : ConvertibleToJava<com.pulumi.aws.ec2.inputs.InstanceNetworkInterfaceArgs> {
    override fun toJava(): com.pulumi.aws.ec2.inputs.InstanceNetworkInterfaceArgs =
        com.pulumi.aws.ec2.inputs.InstanceNetworkInterfaceArgs.builder()
            .deleteOnTermination(deleteOnTermination?.applyValue({ args0 -> args0 }))
            .deviceIndex(deviceIndex.applyValue({ args0 -> args0 }))
            .networkCardIndex(networkCardIndex?.applyValue({ args0 -> args0 }))
            .networkInterfaceId(networkInterfaceId.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [InstanceNetworkInterfaceArgs].
 */
@PulumiTagMarker
public class InstanceNetworkInterfaceArgsBuilder internal constructor() {
    private var deleteOnTermination: Output<Boolean>? = null

    private var deviceIndex: Output<Int>? = null

    private var networkCardIndex: Output<Int>? = null

    private var networkInterfaceId: Output<String>? = null

    /**
     * @param value Whether or not to delete the network interface on instance termination. Defaults to `false`. Currently, the only valid value is `false`, as this is only supported when creating new network interfaces when launching an instance.
     */
    @JvmName("takmkfbevaimkmuf")
    public suspend fun deleteOnTermination(`value`: Output<Boolean>) {
        this.deleteOnTermination = value
    }

    /**
     * @param value Integer index of the network interface attachment. Limited by instance type.
     */
    @JvmName("ofxhalovgsogmhxb")
    public suspend fun deviceIndex(`value`: Output<Int>) {
        this.deviceIndex = value
    }

    /**
     * @param value Integer index of the network card. Limited by instance type. The default index is `0`.
     */
    @JvmName("kdpllxkxpoeaidpu")
    public suspend fun networkCardIndex(`value`: Output<Int>) {
        this.networkCardIndex = value
    }

    /**
     * @param value ID of the network interface to attach.
     */
    @JvmName("rxqsohmgpgweyenp")
    public suspend fun networkInterfaceId(`value`: Output<String>) {
        this.networkInterfaceId = value
    }

    /**
     * @param value Whether or not to delete the network interface on instance termination. Defaults to `false`. Currently, the only valid value is `false`, as this is only supported when creating new network interfaces when launching an instance.
     */
    @JvmName("bgvxswsloqpmmjlf")
    public suspend fun deleteOnTermination(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.deleteOnTermination = mapped
    }

    /**
     * @param value Integer index of the network interface attachment. Limited by instance type.
     */
    @JvmName("ddqbvcrjmrkwvjkv")
    public suspend fun deviceIndex(`value`: Int) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.deviceIndex = mapped
    }

    /**
     * @param value Integer index of the network card. Limited by instance type. The default index is `0`.
     */
    @JvmName("lidfwatxuuhpvmur")
    public suspend fun networkCardIndex(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.networkCardIndex = mapped
    }

    /**
     * @param value ID of the network interface to attach.
     */
    @JvmName("orxednpylwfvoflo")
    public suspend fun networkInterfaceId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.networkInterfaceId = mapped
    }

    internal fun build(): InstanceNetworkInterfaceArgs = InstanceNetworkInterfaceArgs(
        deleteOnTermination = deleteOnTermination,
        deviceIndex = deviceIndex ?: throw PulumiNullFieldException("deviceIndex"),
        networkCardIndex = networkCardIndex,
        networkInterfaceId = networkInterfaceId ?: throw PulumiNullFieldException("networkInterfaceId"),
    )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/ec2/kotlin/inputs/InstanceNetworkInterfaceArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.ec2.kotlin.inputs

import com.pulumi.aws.ec2.inputs.InstanceNetworkInterfaceArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property deleteOnTermination Whether or not to delete the network interface on instance termination. Defaults to `false`. Currently, the only valid value is `false`, as this is only supported when creating new network interfaces when launching an instance.
 * @property deviceIndex Integer index of the network interface attachment. Limited by instance type.
 * @property networkCardIndex Integer index of the network card. Limited by instance type. The default index is `0`.
 * @property networkInterfaceId ID of the network interface to attach.
 */
public data class InstanceNetworkInterfaceArgs(
    public val deleteOnTermination: Output<Boolean>? = null,
    public val deviceIndex: Output<Int>,
    public val networkCardIndex: Output<Int>? = null,
    public val networkInterfaceId: Output<String>,
) : ConvertibleToJava<com.pulumi.aws.ec2.inputs.InstanceNetworkInterfaceArgs> {
    override fun toJava(): com.pulumi.aws.ec2.inputs.InstanceNetworkInterfaceArgs =
        com.pulumi.aws.ec2.inputs.InstanceNetworkInterfaceArgs.builder()
            .deleteOnTermination(deleteOnTermination?.applyValue({ args0 -> args0 }))
            .deviceIndex(deviceIndex.applyValue({ args0 -> args0 }))
            .networkCardIndex(networkCardIndex?.applyValue({ args0 -> args0 }))
            .networkInterfaceId(networkInterfaceId.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [InstanceNetworkInterfaceArgs].
 */
@PulumiTagMarker
public class InstanceNetworkInterfaceArgsBuilder internal constructor() {
    private var deleteOnTermination: Output<Boolean>? = null

    private var deviceIndex: Output<Int>? = null

    private var networkCardIndex: Output<Int>? = null

    private var networkInterfaceId: Output<String>? = null

    /**
     * @param value Whether or not to delete the network interface on instance termination. Defaults to `false`. Currently, the only valid value is `false`, as this is only supported when creating new network interfaces when launching an instance.
     */
    @JvmName("agwiqfxphuxwwcnv")
    public suspend fun deleteOnTermination(`value`: Output<Boolean>) {
        this.deleteOnTermination = value
    }

    /**
     * @param value Integer index of the network interface attachment. Limited by instance type.
     */
    @JvmName("cgnscylkxewlblpq")
    public suspend fun deviceIndex(`value`: Output<Int>) {
        this.deviceIndex = value
    }

    /**
     * @param value Integer index of the network card. Limited by instance type. The default index is `0`.
     */
    @JvmName("tybanrdrqbdovash")
    public suspend fun networkCardIndex(`value`: Output<Int>) {
        this.networkCardIndex = value
    }

    /**
     * @param value ID of the network interface to attach.
     */
    @JvmName("rouuvjfblbkxeptf")
    public suspend fun networkInterfaceId(`value`: Output<String>) {
        this.networkInterfaceId = value
    }

    /**
     * @param value Whether or not to delete the network interface on instance termination. Defaults to `false`. Currently, the only valid value is `false`, as this is only supported when creating new network interfaces when launching an instance.
     */
    @JvmName("vugmclmvlsalxtra")
    public suspend fun deleteOnTermination(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.deleteOnTermination = mapped
    }

    /**
     * @param value Integer index of the network interface attachment. Limited by instance type.
     */
    @JvmName("wosdfhtrfrytjjcc")
    public suspend fun deviceIndex(`value`: Int) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.deviceIndex = mapped
    }

    /**
     * @param value Integer index of the network card. Limited by instance type. The default index is `0`.
     */
    @JvmName("gxbvyovjvmarwokp")
    public suspend fun networkCardIndex(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.networkCardIndex = mapped
    }

    /**
     * @param value ID of the network interface to attach.
     */
    @JvmName("iweeipgtmdycqgrn")
    public suspend fun networkInterfaceId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.networkInterfaceId = mapped
    }

    internal fun build(): InstanceNetworkInterfaceArgs = InstanceNetworkInterfaceArgs(
        deleteOnTermination = deleteOnTermination,
        deviceIndex = deviceIndex ?: throw PulumiNullFieldException("deviceIndex"),
        networkCardIndex = networkCardIndex,
        networkInterfaceId = networkInterfaceId ?: throw PulumiNullFieldException("networkInterfaceId"),
    )
}
